@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.4
+v2.0.0
 dpt_runtime/not_implemented_class.py
 """
 
@@ -22,7 +22,7 @@ dpt_runtime/not_implemented_class.py
 try: from types import new_class
 except ImportError: new_class = None
 
-from .not_implemented_exception import NotImplementedException
+from .exceptions import NotImplementedException
 
 class _NotImplementedMetaClass(type):
     """
